import { Component } from '@angular/core';
import { NavController, AlertController } from '@ionic/angular';
import Parse from 'parse';

@Component({
  selector: 'app-create-post',
  templateUrl: './create-post.page.html',
  styleUrls: ['./create-post.page.scss'],
})
export class CreatePostPage {
  title: string = '';
  content: string = '';
  image: string = '';

  constructor(private navCtrl: NavController, private alertCtrl: AlertController) {}

  async uploadImage() {
    // 实现上传图片的逻辑
    const alert = await this.alertCtrl.create({
      header: '上传图片',
      inputs: [
        {
          name: 'imageUrl',
          type: 'url',
          placeholder: '输入图片URL'
        }
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '上传',
          handler: (data) => {
            this.image = data.imageUrl;
          }
        }
      ]
    });

    await alert.present();
  }

  async submitPost() {
    if (!this.title || !this.content) {
      const alert = await this.alertCtrl.create({
        header: '错误',
        message: '标题和正文不能为空',
        buttons: ['确定']
      });
      await alert.present();
      return;
    }

    const currentUser = Parse.User.current();
    if (!currentUser) {
      const alert = await this.alertCtrl.create({
        header: '错误',
        message: '请先登录',
        buttons: ['确定']
      });
      await alert.present();
      return;
    }

    const Post240709 = Parse.Object.extend('Post240709');
    const post = new Post240709();
    post.set('title', this.title);  
    post.set('content', this.content);
    post.set('imageUrl', this.image);
    post.set('author', currentUser);

    try {
      await post.save();
      this.navCtrl.navigateBack('/home');
    } catch (error) {
      console.error('Error while creating post:', error);
      const alert = await this.alertCtrl.create({
        header: '错误',
        message: '发布失败，请重试',
        buttons: ['确定']
      });
      await alert.present();
    }
  }
}
